use crate::formatter::format::FormatError;
use crate::formatter::FormatConfigError;
use crate::parser::ByteArrayParseErr;
use std::error::Error;
use std::fmt::{Display, Formatter};

#[derive(Debug)]
#[allow(clippy::enum_variant_names)]
pub enum FormatyError {
    ByteArrayParseError(ByteArrayParseErr),
    FormatError(FormatError),
    FormatConfigError(FormatConfigError),
}

impl From<ByteArrayParseErr> for FormatyError {
    fn from(e: ByteArrayParseErr) -> Self {
        Self::ByteArrayParseError(e)
    }
}

impl From<FormatError> for FormatyError {
    fn from(e: FormatError) -> Self {
        Self::FormatError(e)
    }
}

impl From<FormatConfigError> for FormatyError {
    fn from(e: FormatConfigError) -> Self {
        Self::FormatConfigError(e)
    }
}

impl Display for FormatyError {
    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
        let err_msg = match self {
            FormatyError::ByteArrayParseError(e) => e.to_string(),
            FormatyError::FormatError(e) => e.to_string(),
            FormatyError::FormatConfigError(e) => e.to_string(),
        };

        write!(f, "{}", err_msg)
    }
}

impl Error for FormatyError {}
